@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 # shortcuts
 #  os and distros
@@ -159,6 +159,19 @@ sub mapping {
       [like_debian,
        [package => 'libcfitsio3-dev']]],
 
+     [cpanmod => 'Astro::WCS::LibWCS',
+      ## not checked:
+      #[os_freebsd,
+      # [package => 'astrometry']],
+      [like_debian,
+       [package => 'libwcstools-dev']]],
+
+     [cpanmod => 'Audio::Ao',
+      [os_freebsd,
+       [package => 'libao']],
+      [like_debian,
+       [package => 'libao-dev']]],
+
      [cpanmod => 'Audio::Extract::PCM',
       # but does not work with freebsd, see https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=205732
       [package => 'sox']],
@@ -181,6 +194,12 @@ sub mapping {
       [like_debian,
        [package => 'libsamplerate0-dev']]],
 
+     [cpanmod => 'Audio::Opusfile',
+      [os_freebsd,
+       [package => 'opusfile']],
+      [like_debian,
+       [package => 'libopusfile-dev']]],
+
      [cpanmod => 'Audio::PortAudio',
       [os_freebsd,
        [package => ['portaudio', 'pkgconf']]],
@@ -266,12 +285,25 @@ sub mapping {
       [os_darwin,
        [package => 'cairo']]],
 
+     [cpanmod => 'Capstone',
+      [os_freebsd,
+       [package => 'capstone']],
+      [like_debian,
+       [package => 'libcapstone-dev']], # but test failures with Capstone 0.6 @ jessie
+     ],
+
      [cpanmod => 'CDB::TinyCDB',
       [os_freebsd,
        [package => 'tinycdb']],
       [like_debian,
        [package => 'libcdb-dev']]],
 
+     [cpanmod => 'CDB_File::Generator',
+      [os_freebsd,
+       [package => 'cdb']],
+      [like_debian,
+       [package => 'freecdb']]],
+
      [cpanmod => 'Chipcard::PCSC',
       # XXX what about freebsd?
       [like_debian,
@@ -279,7 +311,7 @@ sub mapping {
 
      [cpanmod => ['ClamAV::Client', 'File::Scan::ClamAV'],
       [os_freebsd,
-       [package => 'clamav']],
+       [package => 'clamav']], # additionally freshclam has to be run at least once, and the clamav-clamd service has to be started
       [like_debian,
        [package => ['clamav-daemon', 'clamav-data']]]],
 
@@ -313,7 +345,7 @@ sub mapping {
       [like_debian,
        [package => 'libcrack2-dev']]],
 
-     [cpanmod => 'Crypt::DH::GMP',
+     [cpanmod => ['Crypt::DH::GMP', 'Math::GMPq', 'Math::GMPz'],
       [os_freebsd,
        [package => 'gmp']],
       [like_debian,
@@ -455,6 +487,11 @@ sub mapping {
       [like_debian,
        [package => ['libsdl1.2-dev', 'libsdl-image1.2-dev', 'libsdl-mixer1.2-dev', 'libglib2.0-dev']]]],
 
+     [cpanmod => 'Devel::IPerl',
+      [like_debian,
+       [package => [qw(libzmq3-dev ipython ipython-notebook libmagic-dev)]], # as specified in https://metacpan.org/source/ZMUGHAL/Devel-IPerl-0.006/README.md
+      ]],
+
      [cpanmod => 'Device::Cdio',
       [like_debian,
        # but still does not work
@@ -552,6 +589,10 @@ sub mapping {
      [cpanmod => 'Finance::MICR::GOCR::Check',
       [package => 'gocr']],
 
+     [cpanmod => 'Finance::TA',
+      [os_freebsd,
+       [package => 'ta-lib']]], # alternative would be Alien::TALib
+
      [cpanmod => 'FTDI::D2XX',
       # neither libftdi nor libftdi1 seem to work on FreeBSD
       [like_debian,
@@ -656,7 +697,7 @@ sub mapping {
       [like_debian,
        [package => 'libwnck-dev']]],
 
-     [cpanmod => 'Gnome2::VFS',
+     [cpanmod => ['Gnome2::VFS', 'VFS::Gnome'],
       [os_freebsd,
        [package => 'gnome-vfs']],
       [like_debian,
@@ -717,6 +758,12 @@ sub mapping {
       [like_debian,
        [package => 'libgtk-3-dev']]],
 
+     [cpanmod => 'Gtk3::SourceView',
+      [os_freebsd,
+       [package => 'gtksourceview3']],
+      [like_debian,
+       [package => 'libgtksourceview-3.0-dev']]],
+
      [cpanmod => 'Gtk3::WebKit',
       [os_freebsd,
        [package => 'webkit-gtk3']],
@@ -833,7 +880,7 @@ sub mapping {
      [cpanmod => 'Image::SubImageFind',
       # XXX what about freebsd?
       [like_debian,
-       [package => ['libmagick++-dev', 'graphicsmagick-libmagick-dev-compat']]]],
+       [package => ['libmagick++-dev | graphicsmagick-libmagick-dev-compat']]]],
 
      [cpanmod => 'Imager',
       [os_freebsd,
@@ -929,6 +976,10 @@ sub mapping {
        # but does not work
        [package => 'libssh-dev']]],
 
+     [cpanmod => 'libsoldout',
+      [os_freebsd,
+       [package => 'libsoldout']]],
+
      [cpanmod => 'Lingua::NATools',
       # XXX what about freebsd?
       [like_debian,
@@ -1079,6 +1130,13 @@ sub mapping {
        [package => 'libnet']], # but build failure with Net-CDP-0.09
      ],
 
+     [cpanmod => 'Net::CUPS',
+      [os_freebsd,
+       [package => 'cups-filters']],
+      [like_debian,
+       [package => ['libcups2-dev', 'libcupsfilters-dev', 'libcupsimage2-dev']]]
+     ],
+
      [cpanmod => 'Net::DBus',
       [os_freebsd,
        [package => ['dbus', 'pkgconf']]],
@@ -1148,7 +1206,8 @@ sub mapping {
      [cpanmod => 'Net::RabbitMQ::Client',
       [os_freebsd,
        [package => 'rabbitmq-c-devel']],
-      # XXX what about debian?
+      [like_debian,
+       [package => 'librabbitmq-dev']], # amqp_tcp_socket.h is provided by this package, but compilation still fails
      ],
 
      [cpanmod => 'Net::SIGTRAN::SCTP',
@@ -1177,7 +1236,8 @@ sub mapping {
      ],
 
      [cpanmod => 'Net::Z3950::ZOOM',
-      # XXX freebsd?
+      [os_freebsd,
+       [package => 'yaz']],
       [like_debian,
        [package => 'libyaz-dev']]],
 
@@ -1206,6 +1266,13 @@ sub mapping {
       [like_debian,
        [package => ['libogg-dev', 'libvorbis-dev']]]],
 
+     [cpanmod => 'OIS',
+      ## ois in freebsd ports is 1.2.0, but 1.3.0 is required
+      #[os_freebsd,
+      # [package => 'ois']],
+      [like_debian,
+       [package => 'libois-dev']]],
+
      [cpanmod => 'OpenGL',
       [os_freebsd,
        [package => 'freeglut']],
@@ -1242,6 +1309,12 @@ sub mapping {
       [like_debian,
        [package => 'libgnome-keyring-dev']]],
 
+     [cpanmod => 'PDL::NetCDF',
+      [os_freebsd,
+       [package => 'netcdf']],
+      [like_debian,
+       [package => 'libnetcdf-dev']]],
+
      [cpanmod => 'PerlQt',
       [like_debian,
        [linuxdistrocodename => 'squeeze',
@@ -1277,6 +1350,11 @@ sub mapping {
      [cpanmod => 'PulseAudio',
       [package => 'pulseaudio']],
 
+     [cpanmod => 'QDBM_File',
+      # XXX debian has libqdbm-dev, but CPAN mod needs patching for -I
+      [os_freebsd,
+       [package => 'qdbm']]],
+
      [cpanmod => 'Qstruct',
       # XXX what about freebsd?
       [like_debian,
@@ -1378,13 +1456,20 @@ sub mapping {
       # XXX what about debian?
      ],
 
+     [cpanmod => 'Systemd::Daemon',
+      [like_debian,
+       [package => 'libsystemd-dev']]],
+
      [cpanmod => 'Tcl',
       [os_freebsd,
-       # compiles, but the tests hang for perls 5.18.x and newer
-       [package => 'tcl84']],
+       [package => 'tcl86 | tcl85 | tcl84']],
       [like_debian,
        [package => 'tcl8.5-dev']]],
 
+     [cpanmod => 'Tcl::pTk',
+      [os_freebsd,
+       [package => 'tk86 | tk85 | tk84']]], # XXX what about debian?
+
      [cpanmod => 'Tcl::Tk', # XXX maybe also Tkx?
       # XXX what about freebsd?
       [like_debian,
